Stan Math Library: stan/math/prim/scal/prob/skew_normal_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

skew_normal_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_SKEW_NORMAL_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_SKEW_NORMAL_RNG_HPP
3
4 #include <boost/random/variate_generator.hpp>
5 #include <boost/math/distributions.hpp>
6 #include <stan/math/prim/scal/err/check_finite.hpp>
7 #include <stan/math/prim/scal/err/check_not_nan.hpp>
8 #include <stan/math/prim/scal/err/check_positive.hpp>
9 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
10 #include <stan/math/prim/scal/fun/owens_t.hpp>
11 #include <stan/math/prim/scal/fun/value_of.hpp>
12 #include <stan/math/prim/scal/fun/constants.hpp>
13 #include <stan/math/prim/scal/prob/uniform_rng.hpp>
14 #include <stan/math/prim/scal/meta/include_summand.hpp>
15
16 namespace stan {
17
18 namespace math {
19
20 template <class RNG>
21 inline double
22 skew_normal_rng(const double mu,
23 const double sigma,
24 const double alpha,
25 RNG& rng) {
26 boost::math::skew_normal_distribution<> dist(mu, sigma, alpha);
27
28 static const char* function("stan::math::skew_normal_rng");
29
30 using stan::math::check_positive;
31 using stan::math::check_finite;
32
33 check_finite(function, "Location parameter", mu);
34 check_finite(function, "Shape parameter", alpha);
35 check_positive(function, "Scale parameter", sigma);
36
37 return quantile(dist, stan::math::uniform_rng(0.0, 1.0, rng));
38 }
39 }
40 }
41 #endif
42
check_not_nan.hpp
check_positive.hpp
stan
Definition: log_sum_exp.hpp:8
stan::math::skew_normal_rng
double skew_normal_rng(const double mu, const double sigma, const double alpha, RNG &rng)
Definition: skew_normal_rng.hpp:22
include_summand.hpp
uniform_rng.hpp
stan::math::check_positive
bool check_positive(const char *function, const char *name, const T_y &y)
Return true if y is positive.
Definition: check_positive.hpp:68
owens_t.hpp
stan::math::uniform_rng
double uniform_rng(const double alpha, const double beta, RNG &rng)
Definition: uniform_rng.hpp:21
stan::math::check_finite
bool check_finite(const char *function, const char *name, const T_y &y)
Return true if y is finite.
Definition: check_finite.hpp:62
constants.hpp
check_finite.hpp
value_of.hpp
stan::math::dist
double dist(const std::vector< double > &x, const std::vector< double > &y)
Definition: dist.hpp:11
check_consistent_sizes.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.